==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Image/Gui/Resources/translations/Image_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl" sourcelanguage="en">
  <context>
    <name>Image_Scaling</name>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="63"/>
      <source>Scale image plane</source>
      <translation>Prilagodi velikost ravnine slike</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="65"/>
      <source>Scales an image plane by defining a distance between two points</source>
      <translation>Spremeni velikost ravnine slike z določitvijo razdalje med dvema točkama</translation>
    </message>
  </context>
  <context>
    <name>Dialog</name>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="134"/>
      <source>Scale image plane</source>
      <translation>Prilagodi velikost ravnine slike</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="135"/>
      <source>Distance [mm]</source>
      <translation>Razdalja [mm]</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="136"/>
      <source>Select first point</source>
      <translation>Izberite prvo točko</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="154"/>
      <source>&lt;font color='red'&gt;Enter distance&lt;/font&gt;</source>
      <translation>&lt;font color='red'&gt;Vnesite razdaljo&lt;/font&gt;</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="157"/>
      <source>&lt;font color='red'&gt;Select ImagePlane&lt;/font&gt;</source>
      <translation>&lt;font color='red'&gt;Izberite ravnino slike&lt;/font&gt;</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="182"/>
      <source>Select second point</source>
      <translation>Izberite drugo točko</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="191"/>
      <source>Select Image Plane and type distance</source>
      <translation>Izberite ravnino slike in vnesite razdaljo</translation>
    </message>
  </context>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Create image plane...</source>
      <translation>Ustvari ravnino slike...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Ustvari ravninsko sliko v prostoru 3D</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location filename="../../Command.cpp" line="53"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="54"/>
      <source>Open...</source>
      <translation>Odpri...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="55"/>
      <source>Open image view</source>
      <translation>Odpri pogled slike</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location filename="../../Command.cpp" line="175"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="176"/>
      <source>Scale...</source>
      <translation>Povečava...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="177"/>
      <source>Image Scaling</source>
      <translation>Velikost slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="332"/>
      <location filename="../../OpenGLImageBox.cpp" line="384"/>
      <source>Image pixel format</source>
      <translation>Zapis slike v slikovnih točkah</translation>
    </message>
    <message>
      <location filename="../../GLImageBox.cpp" line="333"/>
      <location filename="../../OpenGLImageBox.cpp" line="385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Nedoločena vrsta barvnega prostora za ogled slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="20"/>
      <source>Image plane</source>
      <translation>Ravnina slike</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="26"/>
      <source>XY-Plane</source>
      <translation type="unfinished">XY-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="36"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="43"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="72"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="81"/>
      <source>Offset:</source>
      <translation type="unfinished">Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="111"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Prilagodi sliko</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="113"/>
      <source>Stretch the image to fit the view</source>
      <translation>Raztegni sliko na velikost pogleda</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="117"/>
      <source>&amp;1:1 scale</source>
      <translation>Merilo &amp;1:1</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="119"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Prikaži sliko v merilu 1:1</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="128"/>
      <source>Standard</source>
      <translation>Običajno</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="146"/>
      <source>Ready...</source>
      <translation>Pripravljeni …</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="539"/>
      <source>grey</source>
      <translation>siva</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="540"/>
      <location filename="../../ImageView.cpp" line="543"/>
      <location filename="../../ImageView.cpp" line="553"/>
      <location filename="../../ImageView.cpp" line="558"/>
      <location filename="../../ImageView.cpp" line="568"/>
      <location filename="../../ImageView.cpp" line="573"/>
      <location filename="../../ImageView.cpp" line="584"/>
      <location filename="../../ImageView.cpp" line="589"/>
      <location filename="../../ImageView.cpp" line="600"/>
      <location filename="../../ImageView.cpp" line="605"/>
      <source>zoom</source>
      <translation>povečava</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="543"/>
      <location filename="../../ImageView.cpp" line="553"/>
      <location filename="../../ImageView.cpp" line="568"/>
      <location filename="../../ImageView.cpp" line="584"/>
      <location filename="../../ImageView.cpp" line="600"/>
      <source>outside image</source>
      <translation>izven slike</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <location filename="../../Command.cpp" line="115"/>
      <source>Images</source>
      <translation>Slike</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <location filename="../../Command.cpp" line="120"/>
      <source>All files</source>
      <translation>Vse datoteke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <location filename="../../Command.cpp" line="122"/>
      <source>Choose an image file to open</source>
      <translation>Izberite sliko, ki jo želite odpreti</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="128"/>
      <source>Error opening image</source>
      <translation>Napaka pri odpiranju slike</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="129"/>
      <source>Could not load the chosen image</source>
      <translation>Izbrane slike ni bilo mogoče naložiti</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="36"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
  </context>
</TS>

==> freecad_0.20.2+dfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Image/Gui/Resources/translations/Image_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="100"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <source>Create image plane...</source>
      <translation>Ustvari ravnino slike...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Ustvari ravninsko sliko v prostoru 3D</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location filename="../../Command.cpp" line="55"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="56"/>
      <source>Open...</source>
      <translation>Odpri...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="57"/>
      <source>Open image view</source>
      <translation>Odpri pogled slike</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location filename="../../Command.cpp" line="175"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="176"/>
      <source>Scale...</source>
      <translation>Povečava...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="177"/>
      <source>Image Scaling</source>
      <translation>Velikost slike</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="150"/>
      <source>Create ImagePlane</source>
      <translation>Ustvari slikovno ravnino</translation>
    </message>
  </context>
  <context>
    <name>Dialog</name>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="138"/>
      <source>Scale image plane</source>
      <translation>Prilagodi velikost ravnine slike</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="139"/>
      <source>Distance [mm]</source>
      <translation>Razdalja [mm]</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="140"/>
      <source>Select first point</source>
      <translation>Izberite prvo točko</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="165"/>
      <source>Enter distance</source>
      <translation>Vnesite razdaljo</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="168"/>
      <source>Select ImagePlane</source>
      <translation>Izberite slikovno ravnino</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="193"/>
      <source>Select second point</source>
      <translation>Izberite drugo točko</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="202"/>
      <source>Select Image Plane and type distance</source>
      <translation>Izberite ravnino slike in vnesite razdaljo</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../OpenGLImageBox.cpp" line="392"/>
      <source>Image pixel format</source>
      <translation>Zapis slike v slikovnih točkah</translation>
    </message>
    <message>
      <location filename="../../OpenGLImageBox.cpp" line="393"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Nedoločena vrsta barvnega prostora za ogled slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="20"/>
      <source>Image plane</source>
      <translation>Ravnina slike</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="26"/>
      <source>XY-Plane</source>
      <translation type="unfinished">XY-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="36"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="43"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="72"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="81"/>
      <source>Offset:</source>
      <translation type="unfinished">Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Prilagodi sliko</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="109"/>
      <source>Stretch the image to fit the view</source>
      <translation>Raztegni sliko na velikost pogleda</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="113"/>
      <source>&amp;1:1 scale</source>
      <translation>Merilo &amp;1:1</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="115"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Prikaži sliko v merilu 1:1</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="124"/>
      <source>Standard</source>
      <translation>Običajno</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="142"/>
      <source>Ready...</source>
      <translation>Pripravljeni …</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="543"/>
      <source>grey</source>
      <translation>siva</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="544"/>
      <location filename="../../ImageView.cpp" line="547"/>
      <location filename="../../ImageView.cpp" line="557"/>
      <location filename="../../ImageView.cpp" line="562"/>
      <location filename="../../ImageView.cpp" line="572"/>
      <location filename="../../ImageView.cpp" line="577"/>
      <location filename="../../ImageView.cpp" line="588"/>
      <location filename="../../ImageView.cpp" line="593"/>
      <location filename="../../ImageView.cpp" line="604"/>
      <location filename="../../ImageView.cpp" line="609"/>
      <source>zoom</source>
      <translation>povečava</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="547"/>
      <location filename="../../ImageView.cpp" line="557"/>
      <location filename="../../ImageView.cpp" line="572"/>
      <location filename="../../ImageView.cpp" line="588"/>
      <location filename="../../ImageView.cpp" line="604"/>
      <source>outside image</source>
      <translation>izven slike</translation>
    </message>
  </context>
  <context>
    <name>Image_Scaling</name>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="56"/>
      <source>Scale image plane</source>
      <translation>Prilagodi velikost ravnine slike</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="60"/>
      <source>Scales an image plane by defining a distance between two points</source>
      <translation>Spremeni velikost ravnine slike z določitvijo razdalje med dvema točkama</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="70"/>
      <location filename="../../Command.cpp" line="114"/>
      <source>Images</source>
      <translation>Slike</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <location filename="../../Command.cpp" line="119"/>
      <source>All files</source>
      <translation>Vse datoteke</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <location filename="../../Command.cpp" line="121"/>
      <source>Choose an image file to open</source>
      <translation>Izberite sliko, ki jo želite odpreti</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="127"/>
      <source>Error opening image</source>
      <translation>Napaka pri odpiranju slike</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="128"/>
      <source>Could not load the chosen image</source>
      <translation>Izbrane slike ni bilo mogoče naložiti</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="32"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
  </context>
</TS>
